package com.ynet.life.log;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.util.formula.CFormula;
import com.ynet.util.formula.LexicalAnalyser;

/* loaded from: com_ynet_life_log.jar:com/ynet/life/log/LifeActionLoggerParser.class */
public class LifeActionLoggerParser {
    private static final String FIELD_VAR_PREFIX = "${";
    private static final String FIELD_VAR_SUFFIX = "}";
    private static final String FIELD_VAR_ICOLL = ".";
    private static final String FIELD_VAR_ICOLL_RET = "|";
    private static final String FIELD_FUN_PREFIX = "@";
    private static final String FIELD_FUN_SUFFIX = ")";
    private static final String FIELD_FUN_ARGFIX = "(";
    private static final String FIELD_EXP_NOTAG = "NOTAG";

    public static String parser(Context context, String logStr) {
        return functionAnalyzer(variableAnalyzer(context, logStr));
    }

    public static String getDataValue(Context context, String fieldName) {
        String fieldValue = null;
        try {
            fieldValue = (String) context.getDataValue(fieldName);
        } catch (GENEException unused) {
        }
        if (fieldValue == null) {
            return "";
        }
        return fieldValue;
    }

    public static String getICollValue(Context context, String iCollName, String key) {
        IndexedCollection icoll;
        int icollSize;
        StringBuffer values = new StringBuffer();
        try {
            icoll = context.getDataElement(iCollName);
            icollSize = icoll.size();
        } catch (Exception unused) {
        }
        if (icollSize == 0) {
            return "";
        }
        for (int i = 0; i < icollSize; i++) {
            KeyedCollection kcoll = icoll.getElementAt(i);
            values.append((String) kcoll.get(key));
            if (i != icollSize - 1) {
                values.append(FIELD_VAR_ICOLL_RET);
            }
        }
        return values.toString();
    }

    private static String variableAnalyzer(Context context, String logStr) {
        int index = 0;
        StringBuffer subContent = new StringBuffer();
        String searchTag = searchTag(logStr, 0, FIELD_VAR_PREFIX, FIELD_VAR_SUFFIX);
        while (true) {
            String tag = searchTag;
            if (!tag.equals(FIELD_EXP_NOTAG)) {
                String fieldName = trimTag(tag, FIELD_VAR_PREFIX, FIELD_VAR_SUFFIX);
                subContent.append(logStr.substring(index, logStr.indexOf(tag, index)));
                subContent.append(getVariableValue(context, fieldName));
                index = logStr.indexOf(tag, index) + tag.length();
                searchTag = searchTag(logStr, index, FIELD_VAR_PREFIX, FIELD_VAR_SUFFIX);
            } else {
                subContent.append(logStr.substring(index, logStr.length()));
                return subContent.toString();
            }
        }
    }

    private static String getVariableValue(Context context, String fieldName) {
        int index1 = fieldName.indexOf(FIELD_VAR_ICOLL, 0);
        if (index1 == -1) {
            return getDataValue(context, fieldName);
        }
        String iCollName = fieldName.substring(0, index1).trim();
        String key = fieldName.substring(index1 + 1).trim();
        return getICollValue(context, iCollName, key);
    }

    private static String functionAnalyzer(String logStr) {
        int index = 0;
        StringBuffer subContent = new StringBuffer();
        String searchTag = searchTag(logStr, 0, FIELD_FUN_PREFIX, FIELD_FUN_SUFFIX);
        while (true) {
            String tag = searchTag;
            if (!tag.equals(FIELD_EXP_NOTAG)) {
                String functionName = trimTag(tag, FIELD_FUN_PREFIX, FIELD_FUN_SUFFIX);
                subContent.append(logStr.substring(index, logStr.indexOf(tag, index)));
                subContent.append(getFunctionValue(functionName));
                index = logStr.indexOf(tag, index) + tag.length();
                searchTag = searchTag(logStr, index, FIELD_FUN_PREFIX, FIELD_FUN_SUFFIX);
            } else {
                subContent.append(logStr.substring(index, logStr.length()));
                return subContent.toString();
            }
        }
    }

    private static String getFunctionValue(String functionName) {
        String method = trimTag(functionName, "", FIELD_FUN_ARGFIX);
        String args = trimTag(functionName, FIELD_FUN_ARGFIX);
        if ("IF".equals(method)) {
            return getFunctionValue_IF(args);
        }
        return functionName;
    }

    private static String getFunctionValue_IF(String args) {
        String result = "";
        int index1 = args.indexOf(",", 0);
        if (index1 == -1) {
            return result;
        }
        String expStr = args.substring(0, index1).trim();
        String trueValue = args.substring(index1 + 1).trim();
        LexicalAnalyser lexical = new LexicalAnalyser();
        try {
            lexical.parseTheFormula(expStr);
            CFormula valueFormula = new CFormula();
            valueFormula.setContent(lexical);
            if (valueFormula.getValue().bBooleanValue()) {
                result = trueValue;
            }
        } catch (Exception unused) {
            result = "";
        }
        return result;
    }

    private static String searchTag(String str, int index, String startWith, String endWith) {
        int index1 = str.indexOf(startWith, index);
        if (index1 == -1) {
            return FIELD_EXP_NOTAG;
        }
        int index2 = str.indexOf(endWith, index);
        if (index2 == -1) {
            return FIELD_EXP_NOTAG;
        }
        if (index2 == index1 + 2) {
            return "";
        }
        return str.substring(index1, index2 + endWith.length());
    }

    private static String trimTag(String tag, String startWith, String endWith) {
        int index1 = tag.indexOf(startWith);
        int index2 = tag.indexOf(endWith);
        return tag.substring(index1 + startWith.length(), index2).trim();
    }

    private static String trimTag(String tag, String startWith) {
        int index1 = tag.indexOf(startWith);
        return tag.substring(index1 + startWith.length()).trim();
    }
}
